@@ -12,7 +12,7 @@ if sys.platform.startswith('win'):
 else:
     import glob
 
-libraryVersion = 'V0.8'
+libraryVersion = 'V0.8.2'
 
 log = logging.getLogger(__name__)
 
@@ -84,7 +84,7 @@ def find_port(baud, timeout):
                 ver = ''
 
             if ver == 'V' or version == "version":
-                print("You need to update the version of the Arduino-Python3",
+                print("You need to update the version of the pyArduinoAPI",
                       "library running on your Arduino.")
                 print("The Arduino sketch is", version)
                 print("The Python installation is", libraryVersion)
@@ -139,7 +139,7 @@ class Arduino(object):
                         ver = ''
 
                     if ver == 'V' or version == "version":
-                        print("You need to update the version of the Arduino-Python3",
+                        print("You need to update the version of the pyArduinoAPI",
                               "library running on your Arduino.")
                         print("The Arduino sketch is", version)
                         print("The Python installation is", libraryVersion)
@@ -155,8 +155,8 @@ class Arduino(object):
     def version(self):
         return get_version(self.sr)
 
-    # Equivalent to the map() function in C++
     def map(self, value, leftMin, leftMax, rightMin, rightMax):
+        """Equivalent to the map() function in the Arduino language."""
         leftSpan = leftMax - leftMin
         rightSpan = rightMax - rightMin
 
@@ -164,6 +164,15 @@ class Arduino(object):
 
         return rightMin + (valueScaled * rightSpan)
 
+    def resetFunc(self):
+        """Resets the board."""
+        cmd_str = build_cmd_str("rb")
+        try:
+            self.sr.write(str.encode(cmd_str))
+            self.sr.flush()
+        except:
+            pass
+
     def digitalWrite(self, pin, val):
         """
         Sends digitalWrite command
@@ -885,4 +894,4 @@ class LCD(object):
             self.sr.write(str.encode(cmd_str))
             self.sr.flush()
         except:
-            pass
\ No newline at end of file
+            pass
